Page 84 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 84

Home

    fornication." The fall of Babylon is also mentioned in at
    least seven verses in the 17th and 18th chapters of

    AS we examine events on the secret side of history
    during the 20th century, our readers can decide for
    themselves whether or not the pattern of these events fits
    Mystery Babylon. They can also decide if this pattern
    matches the program laid down by Adam Weishaupt to
    destroy all religion, overthrow all governments, and rule
    the world.

    79

    Mystery Babylon Unveiled

    Revelation.